@@ -775,7 +775,7 @@ class RPath(RORPath):
 		"""Make a special file with specified type, and major/minor nums"""
 		cmdlist = ['mknod', self.path, type, str(major), str(minor)]
 		if self.conn.os.spawnvp(os.P_WAIT, 'mknod', cmdlist) != 0:
-			RPathException("Error running %s" % cmdlist)
+			raise RPathException("Error running %s" % cmdlist)
 		if type == 'c': datatype = 'chr'
 		elif type == 'b': datatype = 'blk'
 		else: raise RPathException
@@ -803,12 +803,13 @@ class RPathFileHook:
 		self.closing_thunk()
 		return result
 
+
 # Import these late to avoid circular dependencies
+import FilenameMapping
 from lazy import *
 from selection import *
 from destructive_stepping import *
 
-
 class RpathDeleter(ITRBranch):
 	"""Delete a directory.  Called by RPath.delete()"""
 	def start_process(self, index, dsrp):
@@ -818,4 +819,6 @@ class RpathDeleter(ITRBranch):
 		if self.dsrp.isdir(): self.dsrp.rmdir()
 		else: self.dsrp.delete()
 
-		
+	def can_fast_process(self, index, dsrp): return not dsrp.isdir()
+	def fast_process(self, index, dsrp): dsrp.delete()
+	
